@@ -9,6 +9,7 @@ import distutils.spawn
 from docker import errors, from_env
 import json
 import logging
+import tempfile
 from os import environ, path, makedirs, chmod, remove, getcwd, chdir, listdir, rmdir
 import re
 import requests
@@ -624,15 +625,22 @@ def test_module(config):
     # Parse template for all instance types and run queries for each one
     for instance_type in INSTANCE_TYPES:
         _logger.info("Deactivating database using instance type: %s", instance_type)
-        queries = deactivate2queries(instance_type)
-        for query in queries:
-            cmd_query = ["/bin/sh", "-c", 'psql test -XtAc "%s" && echo "pass"' % query]
-            query_res = exec_cmd(config['container_name'], cmd_query, 'odoo')
-            query_res_lines = query_res.splitlines()
-            if "pass" in query_res_lines[-1:]:
-                continue
-            _logger.error('query error "%s" Result: "%s"', query, query_res_lines[:-1])
-            success = False
+        sql_container_fname = "/tmp/%s.sql" % instance_type
+        with tempfile.NamedTemporaryFile("w") as f_sql:
+            # Using ROLLBACK in order to avoid errors because of constraints
+            # e.g. "CREATE ROLE" more than one time raises "already exists"
+            f_sql.write("BEGIN;\n%s\nROLLBACK;" % join_prefix_suffix(
+                deactivate2queries(instance_type), prefix="", suffix=";"))
+            f_sql.flush()
+            subprocess.call(["docker", "cp", f_sql.name, "%s:%s" % (config['container_name'], sql_container_fname)])
+        exec_cmd(config['container_name'], ["chown", "odoo:odoo", sql_container_fname])
+        cmd_query = ["/bin/sh", "-c", 'psql test -aXtAf "%s" && echo "pass"' % sql_container_fname]
+        query_res = exec_cmd(config['container_name'], cmd_query, 'odoo')
+        query_res_lines = query_res.splitlines()
+        if "pass" in query_res_lines[-1:]:
+            continue
+        _logger.error("Result deactivating database using instance type: %s\n%s", instance_type, '\n'.join(query_res_lines))
+        success = False
     return success
 
 def copy_files(src, dst):
